pub(crate) struct Cli {
pub(crate) proxy: Option<Url>,
pub(crate) verbose: bool,
}Expand description
A command line example showcasing how to login using a QR code.
Another device, which will display the QR code is needed to use this example.
Fields
proxy: Option<Url>Set the proxy that should be used for the connection.
verbose: boolEnable verbose logging output.